# AutoXGB

XGBoost + Optuna:  no brainer

- auto train xgboost directly from CSV files
- auto tune xgboost using optuna
- auto serve best xgboot model using fastapi


More details coming soon

NOTE: Not accepting any PRs currently!
